package com.soss.system.weixin.util;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.bean.WxMaSubscribeMessage;
import com.soss.system.domain.Order;
import com.soss.system.domain.Shop;
import com.soss.system.mapper.ShopMapper;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.error.WxErrorException;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
@Component
@Slf4j
public class SendMessageUtils {
    @Autowired
    private WxMaService wxMaService;
    @Value("${weixin.templateId}")
    private String templateId;
    @Value("${weixin.pagePath}")
    private String pagePath;
    @Autowired
    private ShopMapper shopMapper;
    /**
     * 设置会议订阅消息
     *
     * @param
     * @return 订阅会议消息
     */
    private  List<WxMaSubscribeMessage.MsgData> setMeetingMsg (Order order) {
        Shop shop = shopMapper.selectShopById(order.getShopId());
        List<WxMaSubscribeMessage.MsgData> dataList = new ArrayList<>();
        //这里要完全按照订阅消息模板详情去设置，thing1 ，thing2...不能变
        WxMaSubscribeMessage.MsgData data1 = new WxMaSubscribeMessage.MsgData();
        data1.setName("character_string1");
        data1.setValue(order.getOrderNo());
        dataList.add(data1);
        WxMaSubscribeMessage.MsgData data2 = new WxMaSubscribeMessage.MsgData();
        data2.setName("thing2");
        data2.setValue(shop.getName());
        dataList.add(data2);
        WxMaSubscribeMessage.MsgData data3 = new WxMaSubscribeMessage.MsgData();
        data3.setName("character_string4");
        data3.setValue(order.getOrderNum());
        dataList.add(data3);
        WxMaSubscribeMessage.MsgData data4 = new WxMaSubscribeMessage.MsgData();
        data4.setName("thing7");
        data4.setValue(shop.getAddress());
        dataList.add(data4);
        return dataList;
    }

    /**
     * 根据模板id发送消息
     *

     */
    public void sendWxMsg(Order order) {
            try {
                WxMaSubscribeMessage.WxMaSubscribeMessageBuilder builder = WxMaSubscribeMessage.builder();
                //发送人openid
                builder.toUser(order.getUserId());
                //发送的模板id
                builder.templateId(templateId);
                //消息主体
                builder.data(setMeetingMsg(order));
                //点击订阅消息的跳转链接（默认是正式发布的小程序页面，当然也可以通过参数进行控制）
                builder.page(pagePath);
                WxMaSubscribeMessage msg = builder.build();
                wxMaService.getMsgService().sendSubscribeMsg(msg);
            } catch (WxErrorException e) {
                log.error("会议通知发送失败，用户openId:{}, 错误码：{},错误信息：{}",
                        order.getUserId(), e.getError().getErrorCode(), e.getError().getErrorMsg());
                //发送失败就发送短信

            }

    }

}
